to_change_score — skchange

Skip to main content
`Ctrl`+`K`

# to_change_score

to_change_score(scorer: BaseCost | BaseChangeScore) → BaseChangeScore

  Convert compatible scorers to a change score.

  Parameters:
    scorerBaseCost or BaseChangeScore

      The scorer to convert to a change score. If a change score is provided, it is returned as is.

  Returns:
    change_scoreBaseChangeScore

      The change score based on the cost function.